@@ -135,12 +135,14 @@ class NodeHandle(web.RequestHandler):
                         SELECT COUNT(*) FROM plot WHERE plotid='{plotid}';
                         """
 
-                        n = cur.execute(content_find)
-
+                        (n,) = cur.execute(content_find).fetchone()
                         if int(n) == 0:
                             content_insert = f"""
                                 INSERT INTO plot (plotid, k, r, b, u, pid, ip, time)
-                                VALUES '{plotid}', {int(h['k'])}, {int(h['r'])}, {int(h['b'])}, {int(h['u'])}, {int(h['pid'])}, '{ipremo}', '{ts}' 
+                                VALUES (
+                                '{plotid}', {int(h['k'])}, {int(h['r'])}, {int(h['b'])},
+                                {int(h['u'])}, {int(h['pid'])}, '{ipremo}', '{ts}'
+                                )
                                ;
                             """
 
